# Matplotlib TUDa

This is a small packages that adds the corporate colors of the TU Darmstadt (see [Corporate Design](https://www.tu-darmstadt.de/media/medien_stabsstelle_km/services/medien_cd/das_bild_der_tu_darmstadt.pdf), pages 18, 19) to Matplotlib.
